@@ -89,41 +89,31 @@ public class CharsetCallback {
      * To avoid dependency on other code, this list is hard coded here.
      * When an ignorable code point is found and is unmappable, the default callbacks
      * will ignore them.
-     * For a list of the default ignorable code points, use this link: http://unicode.org/cldr/utility/list-unicodeset.jsp?a=[%3ADI%3A]&g=
-     *
-     * This list should be sync with the one in ucnv_err.c
+     * For a list of the default ignorable code points, use this link:
+     * https://unicode.org/cldr/utility/list-unicodeset.jsp?a=%5B%3ADI%3A%5D&abb=on&g=&i=
      *
+     * This list should be sync with the one in ucnv_err.cpp.
      */
     private static boolean IS_DEFAULT_IGNORABLE_CODE_POINT(int c) {
-        return ((c == 0x00AD) ||
-                (c == 0x034F) ||
-                (c == 0x061C) ||
-                (c == 0x115F) ||
-                (c == 0x1160) ||
-                (0x17B4 <= c && c <= 0x17B5) ||
-                (0x180B <= c && c <= 0x180E) ||
-                (0x200B <= c && c <= 0x200F) ||
-                (0x202A <= c && c <= 0x202E) ||
-                (c == 0x2060) ||
-                (0x2066 <= c && c <= 0x2069) ||
-                (0x2061 <= c && c <= 0x2064) ||
-                (0x206A <= c && c <= 0x206F) ||
-                (c == 0x3164) ||
-                (0x0FE00 <= c && c <= 0x0FE0F) ||
-                (c == 0x0FEFF) ||
-                (c == 0x0FFA0) ||
-                (0x01BCA0  <= c && c <= 0x01BCA3) ||
-                (0x01D173 <= c && c <= 0x01D17A) ||
-                (c == 0x0E0001) ||
-                (0x0E0020 <= c && c <= 0x0E007F) ||
-                (0x0E0100 <= c && c <= 0x0E01EF) ||
-                (c == 0x2065) ||
-                (0x0FFF0 <= c && c <= 0x0FFF8) ||
-                (c == 0x0E0000) ||
-                (0x0E0002 <= c && c <= 0x0E001F) ||
-                (0x0E0080 <= c && c <= 0x0E00FF) ||
-                (0x0E01F0 <= c && c <= 0x0E0FFF)
-                );
+        return
+            (c == 0x00AD) ||
+            (c == 0x034F) ||
+            (c == 0x061C) ||
+            (c == 0x115F) ||
+            (c == 0x1160) ||
+            (0x17B4 <= c && c <= 0x17B5) ||
+            (0x180B <= c && c <= 0x180E) ||
+            (0x200B <= c && c <= 0x200F) ||
+            (0x202A <= c && c <= 0x202E) ||
+            (0x2060 <= c && c <= 0x206F) ||
+            (c == 0x3164) ||
+            (0xFE00 <= c && c <= 0xFE0F) ||
+            (c == 0xFEFF) ||
+            (c == 0xFFA0) ||
+            (0xFFF0 <= c && c <= 0xFFF8) ||
+            (0x1BCA0 <= c && c <= 0x1BCA3) ||
+            (0x1D173 <= c && c <= 0x1D17A) ||
+            (0xE0000 <= c && c <= 0xE0FFF);
     }
     /**
      * Decoder Callback interface
