@@ -5,45 +5,57 @@ package com.ibm.icu.number;
 import java.math.BigDecimal;
 import java.math.MathContext;
 
-import com.ibm.icu.impl.StandardPlural;
 import com.ibm.icu.impl.number.AffixPatternProvider;
-import com.ibm.icu.impl.number.AffixUtils;
+import com.ibm.icu.impl.number.CurrencyPluralInfoAffixProvider;
 import com.ibm.icu.impl.number.CustomSymbolCurrency;
 import com.ibm.icu.impl.number.DecimalFormatProperties;
+import com.ibm.icu.impl.number.Grouper;
 import com.ibm.icu.impl.number.MacroProps;
-import com.ibm.icu.impl.number.MultiplierImpl;
 import com.ibm.icu.impl.number.Padder;
 import com.ibm.icu.impl.number.PatternStringParser;
-import com.ibm.icu.impl.number.PatternStringParser.ParsedPatternInfo;
+import com.ibm.icu.impl.number.PropertiesAffixPatternProvider;
 import com.ibm.icu.impl.number.RoundingUtils;
 import com.ibm.icu.number.NumberFormatter.DecimalSeparatorDisplay;
 import com.ibm.icu.number.NumberFormatter.SignDisplay;
-import com.ibm.icu.number.Rounder.FractionRounderImpl;
-import com.ibm.icu.number.Rounder.IncrementRounderImpl;
-import com.ibm.icu.number.Rounder.SignificantRounderImpl;
+import com.ibm.icu.number.Precision.FractionRounderImpl;
+import com.ibm.icu.number.Precision.IncrementRounderImpl;
+import com.ibm.icu.number.Precision.SignificantRounderImpl;
 import com.ibm.icu.text.CompactDecimalFormat.CompactStyle;
-import com.ibm.icu.text.CurrencyPluralInfo;
 import com.ibm.icu.text.DecimalFormatSymbols;
+import com.ibm.icu.text.PluralRules;
 import com.ibm.icu.util.Currency;
 import com.ibm.icu.util.Currency.CurrencyUsage;
 import com.ibm.icu.util.ULocale;
 
 /**
  * <p>
- * This class, as well as NumberFormatterImpl, could go into the impl package, but they depend on too many
- * package-private members of the public APIs.
+ * This class, as well as NumberFormatterImpl, could go into the impl package, but they depend on too
+ * many package-private members of the public APIs.
  */
 final class NumberPropertyMapper {
 
     /** Convenience method to create a NumberFormatter directly from Properties. */
-    public static UnlocalizedNumberFormatter create(DecimalFormatProperties properties, DecimalFormatSymbols symbols) {
+    public static UnlocalizedNumberFormatter create(
+            DecimalFormatProperties properties,
+            DecimalFormatSymbols symbols) {
         MacroProps macros = oldToNew(properties, symbols, null);
         return NumberFormatter.with().macros(macros);
     }
 
+    /** Convenience method to create a NumberFormatter directly from Properties. */
+    public static UnlocalizedNumberFormatter create(
+            DecimalFormatProperties properties,
+            DecimalFormatSymbols symbols,
+            DecimalFormatProperties exportedProperties) {
+        MacroProps macros = oldToNew(properties, symbols, exportedProperties);
+        return NumberFormatter.with().macros(macros);
+    }
+
     /**
-     * Convenience method to create a NumberFormatter directly from a pattern string. Something like this could become
-     * public API if there is demand.
+     * Convenience method to create a NumberFormatter directly from a pattern string. Something like this
+     * could become public API if there is demand.
+     *
+     * NOTE: This appears to be dead code.
      */
     public static UnlocalizedNumberFormatter create(String pattern, DecimalFormatSymbols symbols) {
         DecimalFormatProperties properties = PatternStringParser.parseToProperties(pattern);
@@ -51,19 +63,22 @@ final class NumberPropertyMapper {
     }
 
     /**
-     * Creates a new {@link MacroProps} object based on the content of a {@link DecimalFormatProperties} object. In
-     * other words, maps Properties to MacroProps. This function is used by the JDK-compatibility API to call into the
-     * ICU 60 fluent number formatting pipeline.
+     * Creates a new {@link MacroProps} object based on the content of a {@link DecimalFormatProperties}
+     * object. In other words, maps Properties to MacroProps. This function is used by the
+     * JDK-compatibility API to call into the ICU 60 fluent number formatting pipeline.
      *
      * @param properties
      *            The property bag to be mapped.
      * @param symbols
      *            The symbols associated with the property bag.
      * @param exportedProperties
-     *            A property bag in which to store validated properties.
+     *            A property bag in which to store validated properties. Used by some DecimalFormat
+     *            getters.
      * @return A new MacroProps containing all of the information in the Properties.
      */
-    public static MacroProps oldToNew(DecimalFormatProperties properties, DecimalFormatSymbols symbols,
+    public static MacroProps oldToNew(
+            DecimalFormatProperties properties,
+            DecimalFormatSymbols symbols,
             DecimalFormatProperties exportedProperties) {
         MacroProps macros = new MacroProps();
         ULocale locale = symbols.getULocale();
@@ -78,7 +93,11 @@ final class NumberPropertyMapper {
         // PLURAL RULES //
         //////////////////
 
-        macros.rules = properties.getPluralRules();
+        PluralRules rules = properties.getPluralRules();
+        if (rules == null && properties.getCurrencyPluralInfo() != null) {
+            rules = properties.getCurrencyPluralInfo().getPluralRules();
+        }
+        macros.rules = rules;
 
         /////////////
         // AFFIXES //
@@ -88,7 +107,7 @@ final class NumberPropertyMapper {
         if (properties.getCurrencyPluralInfo() == null) {
             affixProvider = new PropertiesAffixPatternProvider(properties);
         } else {
-            affixProvider = new CurrencyPluralInfoAffixProvider(properties.getCurrencyPluralInfo());
+            affixProvider = new CurrencyPluralInfoAffixProvider(properties.getCurrencyPluralInfo(), properties);
         }
         macros.affixProvider = affixProvider;
 
@@ -96,8 +115,10 @@ final class NumberPropertyMapper {
         // UNITS //
         ///////////
 
-        boolean useCurrency = ((properties.getCurrency() != null) || properties.getCurrencyPluralInfo() != null
-                || properties.getCurrencyUsage() != null || affixProvider.hasCurrencySign());
+        boolean useCurrency = ((properties.getCurrency() != null)
+                || properties.getCurrencyPluralInfo() != null
+                || properties.getCurrencyUsage() != null
+                || affixProvider.hasCurrencySign());
         Currency currency = CustomSymbolCurrency.resolve(properties.getCurrency(), locale, symbols);
         CurrencyUsage currencyUsage = properties.getCurrencyUsage();
         boolean explicitCurrencyUsage = currencyUsage != null;
@@ -122,8 +143,8 @@ final class NumberPropertyMapper {
         MathContext mathContext = RoundingUtils.getMathContextOrUnlimited(properties);
         boolean explicitMinMaxFrac = minFrac != -1 || maxFrac != -1;
         boolean explicitMinMaxSig = minSig != -1 || maxSig != -1;
-        // Resolve min/max frac for currencies, required for the validation logic and for when minFrac or maxFrac was
-        // set (but not both) on a currency instance.
+        // Resolve min/max frac for currencies, required for the validation logic and for when minFrac or
+        // maxFrac was set (but not both) on a currency instance.
         // NOTE: Increments are handled in "Rounder.constructCurrency()".
         if (useCurrency) {
             if (minFrac == -1 && maxFrac == -1) {
@@ -143,35 +164,38 @@ final class NumberPropertyMapper {
         if (minInt == 0 && maxFrac != 0) {
             // Force a digit after the decimal point.
             minFrac = minFrac <= 0 ? 1 : minFrac;
-            maxFrac = maxFrac < 0 ? Integer.MAX_VALUE : maxFrac < minFrac ? minFrac : maxFrac;
+            maxFrac = maxFrac < 0 ? -1 : maxFrac < minFrac ? minFrac : maxFrac;
             minInt = 0;
             maxInt = maxInt < 0 ? -1 : maxInt > RoundingUtils.MAX_INT_FRAC_SIG ? -1 : maxInt;
         } else {
             // Force a digit before the decimal point.
             minFrac = minFrac < 0 ? 0 : minFrac;
-            maxFrac = maxFrac < 0 ? Integer.MAX_VALUE : maxFrac < minFrac ? minFrac : maxFrac;
+            maxFrac = maxFrac < 0 ? -1 : maxFrac < minFrac ? minFrac : maxFrac;
             minInt = minInt <= 0 ? 1 : minInt > RoundingUtils.MAX_INT_FRAC_SIG ? 1 : minInt;
-            maxInt = maxInt < 0 ? -1 : maxInt < minInt ? minInt : maxInt > RoundingUtils.MAX_INT_FRAC_SIG ? -1 : maxInt;
+            maxInt = maxInt < 0 ? -1
+                    : maxInt < minInt ? minInt : maxInt > RoundingUtils.MAX_INT_FRAC_SIG ? -1 : maxInt;
         }
-        Rounder rounding = null;
+        Precision rounding = null;
         if (explicitCurrencyUsage) {
-            rounding = Rounder.constructCurrency(currencyUsage).withCurrency(currency);
+            rounding = Precision.constructCurrency(currencyUsage).withCurrency(currency);
         } else if (roundingIncrement != null) {
-            rounding = Rounder.constructIncrement(roundingIncrement);
+            rounding = Precision.constructIncrement(roundingIncrement);
         } else if (explicitMinMaxSig) {
-            minSig = minSig < 1 ? 1 : minSig > RoundingUtils.MAX_INT_FRAC_SIG ? RoundingUtils.MAX_INT_FRAC_SIG : minSig;
+            minSig = minSig < 1 ? 1
+                    : minSig > RoundingUtils.MAX_INT_FRAC_SIG ? RoundingUtils.MAX_INT_FRAC_SIG : minSig;
             maxSig = maxSig < 0 ? RoundingUtils.MAX_INT_FRAC_SIG
                     : maxSig < minSig ? minSig
-                            : maxSig > RoundingUtils.MAX_INT_FRAC_SIG ? RoundingUtils.MAX_INT_FRAC_SIG : maxSig;
-            rounding = Rounder.constructSignificant(minSig, maxSig);
+                            : maxSig > RoundingUtils.MAX_INT_FRAC_SIG ? RoundingUtils.MAX_INT_FRAC_SIG
+                                    : maxSig;
+            rounding = Precision.constructSignificant(minSig, maxSig);
         } else if (explicitMinMaxFrac) {
-            rounding = Rounder.constructFraction(minFrac, maxFrac);
+            rounding = Precision.constructFraction(minFrac, maxFrac);
         } else if (useCurrency) {
-            rounding = Rounder.constructCurrency(currencyUsage);
+            rounding = Precision.constructCurrency(currencyUsage);
         }
         if (rounding != null) {
             rounding = rounding.withMode(mathContext);
-            macros.rounder = rounding;
+            macros.precision = rounding;
         }
 
         ///////////////////
@@ -184,22 +208,14 @@ final class NumberPropertyMapper {
         // GROUPING STRATEGY //
         ///////////////////////
 
-        int grouping1 = properties.getGroupingSize();
-        int grouping2 = properties.getSecondaryGroupingSize();
-        int minGrouping = properties.getMinimumGroupingDigits();
-        assert grouping1 >= -2; // value of -2 means to forward no grouping information
-        grouping1 = grouping1 > 0 ? grouping1 : grouping2 > 0 ? grouping2 : grouping1;
-        grouping2 = grouping2 > 0 ? grouping2 : grouping1;
-        // TODO: Is it important to handle minGrouping > 2?
-        macros.grouper = Grouper.getInstance((byte) grouping1, (byte) grouping2, minGrouping == 2);
+        macros.grouping = Grouper.forProperties(properties);
 
         /////////////
         // PADDING //
         /////////////
 
         if (properties.getFormatWidth() != -1) {
-            macros.padder = new Padder(properties.getPadString(), properties.getFormatWidth(),
-                    properties.getPadPosition());
+            macros.padder = Padder.forProperties(properties);
         }
 
         ///////////////////////////////
@@ -245,21 +261,22 @@ final class NumberPropertyMapper {
                     properties.getExponentSignAlwaysShown() ? SignDisplay.ALWAYS : SignDisplay.AUTO);
             // Scientific notation also involves overriding the rounding mode.
             // TODO: Overriding here is a bit of a hack. Should this logic go earlier?
-            if (macros.rounder instanceof FractionRounder) {
-                // For the purposes of rounding, get the original min/max int/frac, since the local variables
+            if (macros.precision instanceof FractionPrecision) {
+                // For the purposes of rounding, get the original min/max int/frac, since the local
+                // variables
                 // have been manipulated for display purposes.
                 int minInt_ = properties.getMinimumIntegerDigits();
                 int minFrac_ = properties.getMinimumFractionDigits();
                 int maxFrac_ = properties.getMaximumFractionDigits();
                 if (minInt_ == 0 && maxFrac_ == 0) {
                     // Patterns like "#E0" and "##E0", which mean no rounding!
-                    macros.rounder = Rounder.constructInfinite().withMode(mathContext);
+                    macros.precision = Precision.constructInfinite().withMode(mathContext);
                 } else if (minInt_ == 0 && minFrac_ == 0) {
                     // Patterns like "#.##E0" (no zeros in the mantissa), which mean round to maxFrac+1
-                    macros.rounder = Rounder.constructSignificant(1, maxFrac_ + 1).withMode(mathContext);
+                    macros.precision = Precision.constructSignificant(1, maxFrac_ + 1).withMode(mathContext);
                 } else {
                     // All other scientific patterns, which mean round to minInt+maxFrac
-                    macros.rounder = Rounder.constructSignificant(minInt_ + minFrac_, minInt_ + maxFrac_)
+                    macros.precision = Precision.constructSignificant(minInt_ + minFrac_, minInt_ + maxFrac_)
                             .withMode(mathContext);
                 }
             }
@@ -285,11 +302,7 @@ final class NumberPropertyMapper {
         // MULTIPLIERS //
         /////////////////
 
-        if (properties.getMagnitudeMultiplier() != 0) {
-            macros.multiplier = new MultiplierImpl(properties.getMagnitudeMultiplier());
-        } else if (properties.getMultiplier() != null) {
-            macros.multiplier = new MultiplierImpl(properties.getMultiplier());
-        }
+        macros.scale = RoundingUtils.scaleFromProperties(properties);
 
         //////////////////////
         // PROPERTY EXPORTS //
@@ -297,14 +310,15 @@ final class NumberPropertyMapper {
 
         if (exportedProperties != null) {
 
+            exportedProperties.setCurrency(currency);
             exportedProperties.setMathContext(mathContext);
             exportedProperties.setRoundingMode(mathContext.getRoundingMode());
             exportedProperties.setMinimumIntegerDigits(minInt);
             exportedProperties.setMaximumIntegerDigits(maxInt == -1 ? Integer.MAX_VALUE : maxInt);
 
-            Rounder rounding_;
-            if (rounding instanceof CurrencyRounder) {
-                rounding_ = ((CurrencyRounder) rounding).withCurrency(currency);
+            Precision rounding_;
+            if (rounding instanceof CurrencyPrecision) {
+                rounding_ = ((CurrencyPrecision) rounding).withCurrency(currency);
             } else {
                 rounding_ = rounding;
             }
@@ -334,178 +348,4 @@ final class NumberPropertyMapper {
 
         return macros;
     }
-
-    private static class PropertiesAffixPatternProvider implements AffixPatternProvider {
-        private final String posPrefix;
-        private final String posSuffix;
-        private final String negPrefix;
-        private final String negSuffix;
-
-        public PropertiesAffixPatternProvider(DecimalFormatProperties properties) {
-            // There are two ways to set affixes in DecimalFormat: via the pattern string (applyPattern), and via the
-            // explicit setters (setPositivePrefix and friends).  The way to resolve the settings is as follows:
-            //
-            // 1) If the explicit setting is present for the field, use it.
-            // 2) Otherwise, follows UTS 35 rules based on the pattern string.
-            //
-            // Importantly, the explicit setters affect only the one field they override.  If you set the positive
-            // prefix, that should not affect the negative prefix.  Since it is impossible for the user of this class
-            // to know whether the origin for a string was the override or the pattern, we have to say that we always
-            // have a negative subpattern and perform all resolution logic here.
-
-            // Convenience: Extract the properties into local variables.
-            // Variables are named with three chars: [p/n][p/s][o/p]
-            // [p/n] => p for positive, n for negative
-            // [p/s] => p for prefix, s for suffix
-            // [o/p] => o for escaped custom override string, p for pattern string
-            String ppo = AffixUtils.escape(properties.getPositivePrefix());
-            String pso = AffixUtils.escape(properties.getPositiveSuffix());
-            String npo = AffixUtils.escape(properties.getNegativePrefix());
-            String nso = AffixUtils.escape(properties.getNegativeSuffix());
-            String ppp = properties.getPositivePrefixPattern();
-            String psp = properties.getPositiveSuffixPattern();
-            String npp = properties.getNegativePrefixPattern();
-            String nsp = properties.getNegativeSuffixPattern();
-
-            if (ppo != null) {
-                posPrefix = ppo;
-            } else if (ppp != null) {
-                posPrefix = ppp;
-            } else {
-                // UTS 35: Default positive prefix is empty string.
-                posPrefix = "";
-            }
-
-            if (pso != null) {
-                posSuffix = pso;
-            } else if (psp != null) {
-                posSuffix = psp;
-            } else {
-                // UTS 35: Default positive suffix is empty string.
-                posSuffix = "";
-            }
-
-            if (npo != null) {
-                negPrefix = npo;
-            } else if (npp != null) {
-                negPrefix = npp;
-            } else {
-                // UTS 35: Default negative prefix is "-" with positive prefix.
-                // Important: We prepend the "-" to the pattern, not the override!
-                negPrefix = ppp == null ? "-" : "-" + ppp;
-            }
-
-            if (nso != null) {
-                negSuffix = nso;
-            } else if (nsp != null) {
-                negSuffix = nsp;
-            } else {
-                // UTS 35: Default negative prefix is the positive prefix.
-                negSuffix = psp == null ? "" : psp;
-            }
-        }
-
-        @Override
-        public char charAt(int flags, int i) {
-            return getStringForFlags(flags).charAt(i);
-        }
-
-        @Override
-        public int length(int flags) {
-            return getStringForFlags(flags).length();
-        }
-
-        private String getStringForFlags(int flags) {
-            boolean prefix = (flags & Flags.PREFIX) != 0;
-            boolean negative = (flags & Flags.NEGATIVE_SUBPATTERN) != 0;
-            if (prefix && negative) {
-                return negPrefix;
-            } else if (prefix) {
-                return posPrefix;
-            } else if (negative) {
-                return negSuffix;
-            } else {
-                return posSuffix;
-            }
-        }
-
-        @Override
-        public boolean positiveHasPlusSign() {
-            return AffixUtils.containsType(posPrefix, AffixUtils.TYPE_PLUS_SIGN)
-                    || AffixUtils.containsType(posSuffix, AffixUtils.TYPE_PLUS_SIGN);
-        }
-
-        @Override
-        public boolean hasNegativeSubpattern() {
-            // See comments in the constructor for more information on why this is always true.
-            return true;
-        }
-
-        @Override
-        public boolean negativeHasMinusSign() {
-            return AffixUtils.containsType(negPrefix, AffixUtils.TYPE_MINUS_SIGN)
-                    || AffixUtils.containsType(negSuffix, AffixUtils.TYPE_MINUS_SIGN);
-        }
-
-        @Override
-        public boolean hasCurrencySign() {
-            return AffixUtils.hasCurrencySymbols(posPrefix) || AffixUtils.hasCurrencySymbols(posSuffix)
-                    || AffixUtils.hasCurrencySymbols(negPrefix) || AffixUtils.hasCurrencySymbols(negSuffix);
-        }
-
-        @Override
-        public boolean containsSymbolType(int type) {
-            return AffixUtils.containsType(posPrefix, type) || AffixUtils.containsType(posSuffix, type)
-                    || AffixUtils.containsType(negPrefix, type) || AffixUtils.containsType(negSuffix, type);
-        }
-    }
-
-    private static class CurrencyPluralInfoAffixProvider implements AffixPatternProvider {
-        private final AffixPatternProvider[] affixesByPlural;
-
-        public CurrencyPluralInfoAffixProvider(CurrencyPluralInfo cpi) {
-            affixesByPlural = new ParsedPatternInfo[StandardPlural.COUNT];
-            for (StandardPlural plural : StandardPlural.VALUES) {
-                affixesByPlural[plural.ordinal()] = PatternStringParser
-                        .parseToPatternInfo(cpi.getCurrencyPluralPattern(plural.getKeyword()));
-            }
-        }
-
-        @Override
-        public char charAt(int flags, int i) {
-            int pluralOrdinal = (flags & Flags.PLURAL_MASK);
-            return affixesByPlural[pluralOrdinal].charAt(flags, i);
-        }
-
-        @Override
-        public int length(int flags) {
-            int pluralOrdinal = (flags & Flags.PLURAL_MASK);
-            return affixesByPlural[pluralOrdinal].length(flags);
-        }
-
-        @Override
-        public boolean positiveHasPlusSign() {
-            return affixesByPlural[StandardPlural.OTHER.ordinal()].positiveHasPlusSign();
-        }
-
-        @Override
-        public boolean hasNegativeSubpattern() {
-            return affixesByPlural[StandardPlural.OTHER.ordinal()].hasNegativeSubpattern();
-        }
-
-        @Override
-        public boolean negativeHasMinusSign() {
-            return affixesByPlural[StandardPlural.OTHER.ordinal()].negativeHasMinusSign();
-        }
-
-        @Override
-        public boolean hasCurrencySign() {
-            return affixesByPlural[StandardPlural.OTHER.ordinal()].hasCurrencySign();
-        }
-
-        @Override
-        public boolean containsSymbolType(int type) {
-            return affixesByPlural[StandardPlural.OTHER.ordinal()].containsSymbolType(type);
-        }
-    }
 }
