@@ -19,12 +19,14 @@ package com.ibm.icu.dev.test.rbbi;
 import java.text.CharacterIterator;
 import java.util.ArrayList;
 import java.util.List;
+import java.util.Locale;
 
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.junit.runners.JUnit4;
 
 import com.ibm.icu.dev.test.TestFmwk;
+import com.ibm.icu.impl.RBBIDataWrapper;
 import com.ibm.icu.text.BreakIterator;
 import com.ibm.icu.text.RuleBasedBreakIterator;
 import com.ibm.icu.util.ULocale;
@@ -488,4 +490,169 @@ public class RBBITest extends TestFmwk {
         assertEquals("", biFr, cloneFr);
         assertEquals("", ULocale.FRENCH, cloneFr.getLocale(ULocale.VALID_LOCALE));
     }
+
+    static class T13512Thread extends Thread {
+        private String fText;
+        public List fBoundaries;
+        public List fExpectedBoundaries;
+
+        T13512Thread(String text) {
+            fText = text;
+            fExpectedBoundaries = getBoundary(fText);
+        }
+        @Override
+        public void run() {
+            for (int i= 0; i<10000; ++i) {
+                fBoundaries = getBoundary(fText);
+                if (!fBoundaries.equals(fExpectedBoundaries)) {
+                    break;
+                }
+            }
+        }
+        private static final BreakIterator BREAK_ITERATOR_CACHE = BreakIterator.getWordInstance(ULocale.ROOT);
+        public static List<Integer> getBoundary(String toParse) {
+            List<Integer> retVal = new ArrayList<Integer>();
+            BreakIterator bi = (BreakIterator) BREAK_ITERATOR_CACHE.clone();
+            bi.setText(toParse);
+            for (int boundary=bi.first(); boundary != BreakIterator.DONE; boundary = bi.next()) {
+                retVal.add(boundary);
+            }
+            return retVal;
+        }
+    }
+
+    @Test
+    public void TestBug13512() {
+        String japanese = "コンピューターは、本質的には数字しか扱うことができません。コンピューターは、文字や記号などのそれぞれに番号を割り振る"
+                + "ことによって扱えるようにします。ユニコードが出来るまでは、これらの番号を割り振る仕組みが何百種類も存在しました。どの一つをとっても、十分な"
+                + "文字を含んではいませんでした。例えば、欧州連合一つを見ても、そのすべての言語をカバーするためには、いくつかの異なる符号化の仕"
+                + "組みが必要でした。英語のような一つの言語に限っても、一つだけの符号化の仕組みでは、一般的に使われるすべての文字、句読点、技術"
+                + "的な記号などを扱うには不十分でした。";
+
+        String thai = "โดยพื้นฐานแล้ว, คอมพิวเตอร์จะเกี่ยวข้องกับเรื่องของตัวเลข. คอมพิวเตอร์จัดเก็บตัวอักษรและอักขระอื่นๆ"
+                + " โดยการกำหนดหมายเลขให้สำหรับแต่ละตัว. ก่อนหน้าที่๊ Unicode จะถูกสร้างขึ้น, ได้มีระบบ encoding "
+                + "อยู่หลายร้อยระบบสำหรับการกำหนดหมายเลขเหล่านี้. ไม่มี encoding ใดที่มีจำนวนตัวอักขระมากเพียงพอ: ยกตัวอย่างเช่น, "
+                + "เฉพาะในกลุ่มสหภาพยุโรปเพียงแห่งเดียว ก็ต้องการหลาย encoding ในการครอบคลุมทุกภาษาในกลุ่ม. "
+                + "หรือแม้แต่ในภาษาเดี่ยว เช่น ภาษาอังกฤษ ก็ไม่มี encoding ใดที่เพียงพอสำหรับทุกตัวอักษร, "
+                + "เครื่องหมายวรรคตอน และสัญลักษณ์ทางเทคนิคที่ใช้กันอยู่ทั่วไป.\n" +
+                "ระบบ encoding เหล่านี้ยังขัดแย้งซึ่งกันและกัน. นั่นก็คือ, ในสอง encoding สามารถใช้หมายเลขเดียวกันสำหรับตัวอักขระสองตัวที่แตกต่างกัน,"
+                + "หรือใช้หมายเลขต่างกันสำหรับอักขระตัวเดียวกัน. ในระบบคอมพิวเตอร์ (โดยเฉพาะเซิร์ฟเวอร์) ต้องมีการสนับสนุนหลาย"
+                + " encoding; และเมื่อข้อมูลที่ผ่านไปมาระหว่างการเข้ารหัสหรือแพล็ตฟอร์มที่ต่างกัน, ข้อมูลนั้นจะเสี่ยงต่อการผิดพลาดเสียหาย.";
+
+        T13512Thread t1 = new T13512Thread(thai);
+        T13512Thread t2 = new T13512Thread(japanese);
+        try {
+            t1.start(); t2.start();
+            t1.join(); t2.join();
+        } catch (Exception e) {
+            fail(e.toString());
+        }
+        assertEquals("", t1.fExpectedBoundaries, t1.fBoundaries);
+        assertEquals("", t2.fExpectedBoundaries, t2.fBoundaries);
+    }
+
+    @Test
+    public void TestBug12677() {
+        // Check that stripping of comments from rules for getRules() is not confused by
+        // the presence of '#' characters in the rules that do not introduce comments.
+        String rules = "!!forward; \n"
+                     + "$x = [ab#];  # a set with a # literal. \n"
+                     + " # .;        # a comment that looks sort of like a rule.   \n"
+                     + " '#' '?';    # a rule with a quoted #   \n";
+
+        RuleBasedBreakIterator bi  = new RuleBasedBreakIterator(rules);
+        String rtRules = bi.toString();        // getRules() in C++
+        assertEquals("Break Iterator rule stripping test", "!!forward; $x = [ab#]; '#' '?'; ",  rtRules);
+    }
+
+    @Test
+    public void TestTableRedundancies() {
+        RuleBasedBreakIterator bi = (RuleBasedBreakIterator)BreakIterator.getLineInstance(Locale.ENGLISH);
+        String rules = bi.toString();
+        bi = new RuleBasedBreakIterator(rules);
+        // Build a break iterator from source rules.
+        // Want to check the rule builder in Java, not the pre-built rules that are imported from ICU4C.
+        RBBIDataWrapper dw = bi.fRData;
+        RBBIDataWrapper.RBBIStateTable fwtbl = dw.fFTable;
+        int numCharClasses = dw.fHeader.fCatCount;
+
+        // Check for duplicate columns (character categories)
+        List<String> columns = new ArrayList<String>();
+        for (int column=0; column<numCharClasses; column++) {
+            StringBuilder s = new StringBuilder();
+            for (int r = 1; r < fwtbl.fNumStates; r++) {
+                int row = dw.getRowIndex(r);
+                short tableVal = fwtbl.fTable[row + RBBIDataWrapper.NEXTSTATES + column];
+                s.append((char)tableVal);
+            }
+            columns.add(s.toString());
+        }
+        // Ignore column (char class) 0 while checking; it's special, and may have duplicates.
+        for (int c1=1; c1<numCharClasses; c1++) {
+            for (int c2 = c1+1; c2 < numCharClasses; c2++) {
+                assertFalse(String.format("Duplicate columns (%d, %d)", c1, c2), columns.get(c1).equals(columns.get(c2)));
+                // if (columns.get(c1).equals(columns.get(c2))) {
+                //    System.out.printf("Duplicate columns (%d, %d)\n", c1, c2);
+                // }
+            }
+        }
+
+        // Check for duplicate states.
+        List<String> rows = new ArrayList<String>();
+        for (int r=0; r<fwtbl.fNumStates; r++) {
+            StringBuilder s = new StringBuilder();
+            int row = dw.getRowIndex(r);
+            assertTrue("Accepting < -1", fwtbl.fTable[row + RBBIDataWrapper.ACCEPTING] >= -1);
+            s.append(fwtbl.fTable[row + RBBIDataWrapper.ACCEPTING]);
+            s.append(fwtbl.fTable[row + RBBIDataWrapper.LOOKAHEAD]);
+            s.append(fwtbl.fTable[row + RBBIDataWrapper.TAGIDX]);
+            for (int column=0; column<numCharClasses; column++) {
+                short tableVal = fwtbl.fTable[row + RBBIDataWrapper.NEXTSTATES + column];
+                s.append((char)tableVal);
+            }
+            rows.add(s.toString());
+        }
+
+        for (int r1=0; r1 < fwtbl.fNumStates; r1++) {
+            for (int r2= r1+1; r2 < fwtbl.fNumStates; r2++) {
+                assertFalse(String.format("Duplicate states (%d, %d)", r1, r2), rows.get(r1).equals(rows.get(r2)));
+                // if (rows.get(r1).equals(rows.get(r2))) {
+                //     System.out.printf("Duplicate states (%d, %d)\n", r1, r2);
+                // }
+            }
+        }
+    }
+
+    @Test
+    public void TestBug13447() {
+        // Bug 13447: verify that getRuleStatus() returns the value corresponding to current(),
+        //  even after next() has returned DONE.
+       RuleBasedBreakIterator bi =
+                (RuleBasedBreakIterator)BreakIterator.getWordInstance(Locale.ENGLISH);
+        bi.setText("1234");
+        assertEquals("", BreakIterator.WORD_NONE, bi.getRuleStatus());
+        assertEquals("", 4, bi.next());
+        assertEquals("", BreakIterator.WORD_NUMBER, bi.getRuleStatus());
+        assertEquals("", BreakIterator.DONE, bi.next());
+        assertEquals("", 4, bi.current());
+        assertEquals("", BreakIterator.WORD_NUMBER, bi.getRuleStatus());
+    }
+
+    @Test
+    public void TestTableRebuild() {
+        // Test to verify that rebuilding the state tables from rule source for the standard
+        // break iterator types yields the same tables as are imported from ICU4C as part of the default data.
+        List<RuleBasedBreakIterator> breakIterators = new ArrayList<RuleBasedBreakIterator>();
+        breakIterators.add((RuleBasedBreakIterator)BreakIterator.getCharacterInstance(Locale.ENGLISH));
+        breakIterators.add((RuleBasedBreakIterator)BreakIterator.getWordInstance(Locale.ENGLISH));
+        breakIterators.add((RuleBasedBreakIterator)BreakIterator.getSentenceInstance(Locale.ENGLISH));
+        breakIterators.add((RuleBasedBreakIterator)BreakIterator.getLineInstance(Locale.ENGLISH));
+
+        for (RuleBasedBreakIterator bi: breakIterators) {
+            String rules = bi.toString();
+            RuleBasedBreakIterator bi2 = new RuleBasedBreakIterator(rules);
+            assertTrue("Forward Table",      RBBIDataWrapper.equals(bi.fRData.fFTable, bi2.fRData.fFTable));
+            assertTrue("Reverse Table",      RBBIDataWrapper.equals(bi.fRData.fRTable, bi2.fRData.fRTable));
+        }
+    }
 }
