@@ -99,12 +99,12 @@ public class RegionTest extends TestFmwk {
             { "BS" , "044", "029", "TERRITORY", "019" },
             { "BT" , "064", "034", "TERRITORY", "142" },
             { "BU" , "104", "035", "TERRITORY", "142" },
-            { "BV" , "074", "QO" , "TERRITORY", "009" },
+            { "BV" , "074", "005", "TERRITORY", "019" },
             { "BW" , "072", "018", "TERRITORY", "002" },
             { "BY" , "112", "151", "TERRITORY", "150" },
             { "BZ" , "084", "013", "TERRITORY", "019" },
             { "CA" , "124", "021", "TERRITORY", "019" },
-            { "CC" , "166", "QO" , "TERRITORY", "009" },
+            { "CC" , "166", "053", "TERRITORY", "009" },
             { "CD" , "180", "017", "TERRITORY", "002" },
             { "CF" , "140", "017", "TERRITORY", "002" },
             { "CG" , "178", "017", "TERRITORY", "002" },
@@ -120,7 +120,7 @@ public class RegionTest extends TestFmwk {
             { "CU" , "192", "029", "TERRITORY", "019" },
             { "CV" , "132", "011", "TERRITORY", "002" },
             { "CW" , "531", "029", "TERRITORY", "019" },
-            { "CX" , "162", "QO" , "TERRITORY", "009" },
+            { "CX" , "162", "053", "TERRITORY", "009" },
             { "CY" , "196", "145", "TERRITORY", "142" },
             { "CZ" , "203", "151", "TERRITORY", "150" },
             { "DD" , "276", "155", "TERRITORY", "150" },
@@ -161,13 +161,13 @@ public class RegionTest extends TestFmwk {
             { "GP" , "312", "029", "TERRITORY", "019" },
             { "GQ" , "226", "017", "TERRITORY", "002" },
             { "GR" , "300", "039", "TERRITORY", "150" },
-            { "GS" , "239", "QO" , "TERRITORY", "009" },
+            { "GS" , "239", "005", "TERRITORY", "019" },
             { "GT" , "320", "013", "TERRITORY", "019" },
             { "GU" , "316", "057", "TERRITORY", "009" },
             { "GW" , "624", "011", "TERRITORY", "002" },
             { "GY" , "328", "005", "TERRITORY", "019" },
             { "HK" , "344", "030", "TERRITORY", "142" },
-            { "HM" , "334", "QO" , "TERRITORY", "009" },
+            { "HM" , "334", "053", "TERRITORY", "009" },
             { "HN" , "340", "013", "TERRITORY", "019" },
             { "HR" , "191", "039", "TERRITORY", "150" },
             { "HT" , "332", "029", "TERRITORY", "019" },
@@ -178,7 +178,7 @@ public class RegionTest extends TestFmwk {
             { "IL" , "376", "145", "TERRITORY", "142" },
             { "IM" , "833", "154", "TERRITORY", "150" },
             { "IN" , "356", "034", "TERRITORY", "142" },
-            { "IO" , "086", "QO" , "TERRITORY", "009" },
+            { "IO" , "086", "014", "TERRITORY", "002" },
             { "IQ" , "368", "145", "TERRITORY", "142" },
             { "IR" , "364", "034", "TERRITORY", "142" },
             { "IS" , "352", "154", "TERRITORY", "150" },
@@ -293,7 +293,7 @@ public class RegionTest extends TestFmwk {
             { "TA" , "-1" , "QO", "TERRITORY", "009" },
             { "TC" , "796", "029", "TERRITORY", "019" },
             { "TD" , "148", "017", "TERRITORY", "002" },
-            { "TF" , "260", "QO" , "TERRITORY", "009" },
+            { "TF" , "260", "145", "TERRITORY", "142" },
             { "TG" , "768", "011", "TERRITORY", "002" },
             { "TH" , "764", "035", "TERRITORY", "142" },
             { "TJ" , "762", "143", "TERRITORY", "142" },
@@ -310,7 +310,7 @@ public class RegionTest extends TestFmwk {
             { "TZ" , "834", "014", "TERRITORY", "002" },
             { "UA" , "804", "151", "TERRITORY", "150" },
             { "UG" , "800", "014", "TERRITORY", "002" },
-            { "UM" , "581", "QO" , "TERRITORY", "009" },
+            { "UM" , "581", "057", "TERRITORY", "009" },
             { "US" , "840", "021", "TERRITORY", "019" },
             { "UY" , "858", "005", "TERRITORY", "019" },
             { "UZ" , "860", "143", "TERRITORY", "142" },
